using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using Infragistics.Win.UltraWinTree;


namespace Infragistics.Win.Samples
{
	#region WinTreeDropTarget class
	/// <summary>
	/// Class which implements the IDropTarget interface for the WinTree control.
	/// </summary>
	public class WinTreeDropTarget : DragDropManager.IDropTarget
	{
		#region Member variables
		
		private UltraTree _tree = null;
		
		#endregion Member variables
	
		#region Constructors

		/// <summary>
		/// Creates a new instance of the <see cref="WinTreeDropTarget"/> class.
		/// </summary>
		/// <param name="tree">The UltraTree control with which this instance is associated.</param>
		public WinTreeDropTarget( UltraTree tree )
		{
			if ( tree == null )
				throw new ArgumentNullException( "tree" );

			this._tree = tree;
		}

		#endregion Constructors

		#region IDropTarget interface implementation

		//	Implements the Control property.
		UltraControlBase DragDropManager.IDropTarget.Control
		{
			get{ return this._tree; }
		}

		//	Handles the OnDropTargetNotify method.
		void DragDropManager.IDropTarget.OnDropTargetNotify( DragDropManager.DropTargetNotifyInfo info )
		{
			UltraTree tree = this._tree;

			switch ( info.DropTargetNotification )
			{
				//	If the drop notification type is 'DragOver', read the state of the
				//	Control key and set the 'Effect' property accordingly, so that the
				//	drag source knows which drag cursor to display, and also whether the
				//	drag data should be removed from the drag source info.
				case DragDropManager.DropTargetNotification.DragOver:
				{
					info.Effect = info.IsControlKeyPressed ? DragDropEffects.Copy : DragDropEffects.Move;
				}
				break;

				//	If the drop notification type is 'DragDrop', add the items to
				//	the drop target's Items collection.
				case DragDropManager.DropTargetNotification.DragDrop:
				{
					IDataObject dataObject = info.Data as IDataObject;
					UltraTreeNode[] nodes = dataObject.GetData( typeof(UltraTreeNode[]) ) as UltraTreeNode[];
					if ( nodes != null )
					{
						//	If we are copying the nodes, clone each oninfo...note that for this
						//	demonstration we will not include subnodes, but this could be easily
						//	changed to support this.
						if ( info.Effect == DragDropEffects.Copy )
						{
							for ( int i = nodes.Length - 1; i >= 0; i -- )
							{
								nodes[i] = nodes[i].Clone() as UltraTreeNode;
							}
						}

						tree.Nodes.AddRange( nodes );
					}
				}
				break;
			}
		}
		#endregion	IDropTarget interface implementation

	}
	#endregion WinTreeDropTarget class
}